@@ -1231,7 +1231,8 @@ bool pkgProblemResolver::InstOrNewPolicyBroken(pkgCache::PkgIterator I)
    }
 
    // a newly broken policy (recommends/suggests) is a problem
-   if (Cache[I].NowPolicyBroken() == false &&
+   if ((Flags[I->ID] & BrokenPolicyAllowed) == 0 &&
+       Cache[I].NowPolicyBroken() == false &&
        Cache[I].InstPolicyBroken() == true)
    {
       if (Debug == true)
@@ -1359,8 +1360,8 @@ bool pkgProblemResolver::ResolveByKeepInternal()
 	       if (Cache[Pkg].InstallVer == 0 ||
 		   Pkg->CurrentVer == 0)
 		  continue;
-	       
-	       if (not Cache[I].Protect())
+
+	       if (not Cache[Pkg].Protect())
 	       {
 		  if (Debug == true)
 		     clog << "  Keeping Package " << Pkg.FullName(false) << " due to " << Start.DepType() << endl;
